color.density <-
function(...) {

  cat("\n"); cat( # stop(call.=FALSE, "\n","------\n",
    ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n",
    " The lessR project is now much more than just about color.\n",
      "Accordingly, the function  color.density has been renamed.\n\n",
      "Now use  dens  instead of  color.density.\n",
    "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n\n", sep="")

  den(...)

  cat("\n"); cat( # stop(call.=FALSE, "\n","------\n",
    ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n",
    " The lessR project is now much more than just about color.\n",
      "Accordingly, the function  color.density has been renamed.\n\n",
      "Now use  dens  instead of  color.density.\n",
    "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n\n", sep="")

}
